@@ -207,6 +207,8 @@ class Bitpin:
         """
 
         self._raise_for_exception(func_name, response, additional)
+        if response.request.method.lower() == 'delete':
+            return {}
         return response.json()
 
     def __request(
